@@ -66,7 +66,7 @@
 	};
 	
 	var minYear = 1890;//最小年限
-	var maxYear = 2100;//最大年限
+	var maxYear = 2101;//最大年限
 	var DATA = {
 		heavenlyStems: ['甲', '乙', '丙', '丁', '戊', '己', '庚', '辛', '壬', '癸'], //天干
 		earthlyBranches: ['子', '丑', '寅', '卯', '辰', '巳', '午', '未', '申', '酉', '戌', '亥'], //地支
@@ -85,7 +85,7 @@
 	
 	worktime.y2018 = {'d0101':2,'d0211':1,'d0215':2,'d0216':2,'d0217':2,'d0218':2,'d0219':2,'d0220':2,'d0221':2,'d0224':1,'d0405':2,'d0406':2,'d0407':2,'d0408':1,'d0428':1,'d0429':2,'d0430':2,'d0501':2,'d0616':2,'d0617':2,'d0618':2,'d0922':2,'d0923':2,'d0924':2,'d0929':1,'d0930':1,'d1001':2,'d1002':2,'d1003':2,'d1004':2,'d1005':2,'d1006':2,'d1007':2,'d1229':1,'d1230':2,'d1231':2};
 
-    	worktime.y2019 = {'d0101':2,'d0202':1,'d0203':1,'d0204':2,'d0205':2,'d0206':2,'d0207':2,'d0208':2,'d0209':2,'d0210':2,'d0405':2,'d0406':2,'d0407':2,'d0501':2,'d0607':2,'d0608':2,'d0609':2,'d0913':2,'d0914':2,'d0915':2,'d0929':1,'d1001':2,'d1002':2,'d1003':2,'d1004':2,'d1005':2,'d1006':2,'d1007':2,'d1012':1};
+    	worktime.y2019 = {'d0101':2,'d0202':1,'d0203':1,'d0204':2,'d0205':2,'d0206':2,'d0207':2,'d0208':2,'d0209':2,'d0210':2,'d0405':2,'d0406':2,'d0407':2,'d0501':2,'d0502':2,'d0503':2,'d0504':2,'d0505':1,'d0607':2,'d0608':2,'d0609':2,'d0913':2,'d0914':2,'d0915':2,'d0929':1,'d1001':2,'d1002':2,'d1003':2,'d1004':2,'d1005':2,'d1006':2,'d1007':2,'d1012':1};
 
     	worktime.y2020 = {'d0101':2,'d0102':2,'d0202':1,'d0203':1,'d0204':2,'d0205':2,'d0206':2,'d0207':2,'d0208':2,'d0209':2,'d0210':2,'d0405':2,'d0406':2,'d0407':2,'d0501':2,'d0607':2,'d0608':2,'d0609':2,'d0913':2,'d0914':2,'d0915':2,'d0929':1,'d1001':2,'d1002':2,'d1003':2,'d1004':2,'d1005':2,'d1006':2,'d1007':2,'d1012':1};
 	
@@ -254,7 +254,7 @@
                          [3,1,22,43320],[0,2,9,26928],[7,1,29,29336],[0,2,17,27296],[0,2,6,44368],
                          [5,1,26,19880],[0,2,14,19296],[0,2,3,42352],[4,1,24,21104],[0,2,10,53856],
                          [8,1,30,59696],[0,2,18,54560],[0,2,7,55968],[6,1,27,27472],[0,2,15,22224],
-                         [0,2,5,19168],[4,1,25,42216],[0,2,12,42192],[0,2,1,53584],[2,1,21,55592],[0,2,9,54560]];
+                         [0,2,5,19168],[4,1,25,42216],[0,2,12,42192],[0,2,1,53584],[2,1,21,55592],[0,2,9,54560],[6,1,29,44448]];
 	
 	/**
 	 * 二十四节气数据，节气点时间（单位是分钟）
