@@ -488,7 +488,7 @@ applet_button_clicked(GtkWidget *w, IndicatorCalendar *d)
 
 static void popup_config(GtkAction *action, gpointer user_data)
 {
-    system("ukui-control-center &");
+    system("ukui-control-center -t &");
 }
 
 static gboolean
@@ -698,8 +698,8 @@ update_time(IndicatorCalendar *d)
 	        markup = update_label(d, (char *)"JUE", year, month, day, hour);
 	    }
 	    else {
-	        markup = update_label(d, (char *)("Thur"), year, month, day, hour);
-	        sprintf(datestr, "%s Thur  %04d/%02d/%02d", d->time.c_str(), year, month, day);
+	        markup = update_label(d, (char *)("Thu"), year, month, day, hour);
+	        sprintf(datestr, "%s Thu  %04d/%02d/%02d", d->time.c_str(), year, month, day);
 	    }
     }
     if (week == 5) {
@@ -894,7 +894,7 @@ static void reposition(GtkWidget *widget, IndicatorCalendar *d)
     int x, y;
     if (d->orientation == GTK_ORIENTATION_HORIZONTAL) {
         if (origin_x + widget_alloc.width > monitor_rect.x + monitor_rect.width)
-            x = monitor_rect.x + monitor_rect.width;
+            x = monitor_rect.x + monitor_rect.width - widget_alloc.width;
         else
             x = origin_x + widget_alloc.width;
 
